==> ms_salesforce_api-2.2.1-py3-none-any.whl: ms_salesforce_api/salesforce/api/opportunity/dto/OpportunityDTO.py <==
from ms_salesforce_api.salesforce.helpers.string import normalize_value


class OpportunityLineItemDTO(object):
    def __init__(
        self,
        product_id,
        profit_center_name,
        country,
        opportunity_id,
        product_name,
        quantity,
        unit_price,
    ):
        self.product_id = product_id
        self.profit_center_name = profit_center_name
        self.country = country
        self.opportunity_id = opportunity_id
        self.product_name = product_name
        self.quantity = quantity
        self.unit_price = unit_price

    @staticmethod
    def from_salesforce_record(line_item_record, opportunity_id):
        product_name = line_item_record.get("FRM_ProductName__c", "")
        quantity = line_item_record.get("Quantity", 0.0)
        unit_price = line_item_record.get("UnitPrice", 0.0)
        product = line_item_record.get("Product2", {})
        profit_center = product.get("LKP_ProfitCenter__r", {})
        profit_center_name = ""
        country = ""

        if profit_center:
            profit_center_name = normalize_value(profit_center.get("Name", ""))
            country = normalize_value(profit_center.get("PCK_Country__c", ""))

        return OpportunityLineItemDTO(
            product_id=product.get("Id", ""),
            profit_center_name=profit_center_name,
            country=country,
            opportunity_id=opportunity_id,
            product_name=product_name,
            quantity=quantity,
            unit_price=unit_price,
        )

    def to_dict(self):
        return {
            "product_id": self.product_id,
            "profit_center_name": self.profit_center_name,
            "country": self.country,
            "opportunity_id": self.opportunity_id,
            "product_name": self.product_name,
            "quantity": self.quantity,
            "unit_price": self.unit_price,
        }


class OpportunityDTO(object):
    def __init__(
        self,
        opportunity_id,
        account_billing_country,
        account_owner,
        account_id,
        amount,
        amount_eur,
        campaign_id,
        close_month_formula,
        close_date,
        contact_id,
        curreny_iso_code,
        end_date,
        expected_revenue,
        fiscal,
        fiscal_quarter,
        fiscal_year,
        jira_default_name,
        ga_client_id,
        ga_track_id,
        ga_user_id,
        is_global,
        has_opportunity_lineitem,
        has_overdue_task,
        hasproposal,
        is_closed,
        is_won,
        jira_component_required,
        jira_estimated_work_load,
        jira_number,
        jira_work_load,
        jira_component_url,
        lead_id,
        lead_source,
        google_funding_opportunity,
        loss_reason,
        market_scope,
        ms_account_company_invoicing,
        ms_account_invoice_country_code,
        ms_company_origin,
        opportunity_name,
        opportunity_name_short,
        opportunity_requestor,
        owner_id,
        probability,
        record_type_id,
        roi_analysis_completed,
        associated_services,
        stage_name,
        start_date,
        tier_short,
        total_opportunity_quantity,
        year_created,
        opportunity_line_items,
        lkp_project,
    ):
        self.opportunity_id = opportunity_id
        self.account_billing_country = account_billing_country
        self.account_owner = account_owner
        self.account_id = account_id
        self.amount = amount
        self.amount_eur = amount_eur
        self.campaign_id = campaign_id
        self.close_month_formula = close_month_formula
        self.close_date = close_date
        self.contact_id = contact_id
        self.curreny_iso_code = curreny_iso_code
        self.end_date = end_date
        self.expected_revenue = expected_revenue
        self.fiscal = fiscal
        self.fiscal_quarter = fiscal_quarter
        self.fiscal_year = fiscal_year
        self.jira_default_name = jira_default_name
        self.ga_client_id = ga_client_id
        self.ga_track_id = ga_track_id
        self.ga_user_id = ga_user_id
        self.is_global = is_global
        self.has_opportunity_lineitem = has_opportunity_lineitem
        self.has_overdue_task = has_overdue_task
        self.hasproposal = hasproposal
        self.is_closed = is_closed
        self.is_won = is_won
        self.jira_component_required = jira_component_required
        self.jira_estimated_work_load = jira_estimated_work_load
        self.jira_number = jira_number
        self.jira_work_load = jira_work_load
        self.jira_component_url = jira_component_url
        self.lead_id = lead_id
        self.lead_source = lead_source
        self.google_funding_opportunity = google_funding_opportunity
        self.loss_reason = loss_reason
        self.market_scope = market_scope
        self.ms_account_company_invoicing = ms_account_company_invoicing
        self.ms_account_invoice_country_code = ms_account_invoice_country_code
        self.ms_company_origin = ms_company_origin
        self.opportunity_name = opportunity_name
        self.opportunity_name_short = opportunity_name_short
        self.opportunity_requestor = opportunity_requestor
        self.owner_id = owner_id
        self.probability = probability
        self.record_type_id = record_type_id
        self.roi_analysis_completed = roi_analysis_completed
        self.associated_services = associated_services
        self.stage_name = stage_name
        self.start_date = start_date
        self.tier_short = tier_short
        self.total_opportunity_quantity = total_opportunity_quantity
        self.year_created = year_created
        self.opportunity_line_items = opportunity_line_items
        self.lkp_project = lkp_project

    @staticmethod
    def from_salesforce_record(record):
        def _get_year_created(key: str):
            try:
                year = int(record[key])
                # We set allways the January first date because they want
                # a Date field for this value.
                return f"{year}-01-01"

            except (TypeError, KeyError):
                return ""

        opportunity_line_items = record.get("OpportunityLineItems", {})
        if opportunity_line_items and isinstance(opportunity_line_items, dict):
            line_items_records = record.get("OpportunityLineItems", {}).get(
                "records", []
            )
            opportunity_line_items = [
                OpportunityLineItemDTO.from_salesforce_record(
                    line_item,
                    record["Id"],
                ).to_dict()
                for line_item in line_items_records
            ]
        else:
            opportunity_line_items = []

        return OpportunityDTO(
            opportunity_id=record["Id"],
            account_billing_country=normalize_value(
                record.get("Account_Billing_Country__c", "")
            ),
            account_owner=normalize_value(record.get("Account_owner__c", "")),
            account_id=normalize_value(record.get("AccountId", "")),
            amount=record.get("Amount", 0.0),
            amount_eur=record.get("Amount_EUR__c", 0.0),
            campaign_id=normalize_value(record.get("CampaignId", "")),
            close_month_formula=normalize_value(
                record.get("Close_Month_Formula__c", "")
            ),
            close_date=normalize_value(record.get("CloseDate", "")),
            contact_id=normalize_value(record.get("ContactId", "")),
            curreny_iso_code=normalize_value(
                record.get("CurrencyIsoCode", "")
            ),
            end_date=normalize_value(record.get("EndDate__c", "")),
            expected_revenue=normalize_value(
                record.get("ExpectedRevenue", "")
            ),
            fiscal=normalize_value(record.get("Fiscal", "")),
            fiscal_quarter=normalize_value(record.get("FiscalQuarter", "")),
            fiscal_year=_get_year_created("FiscalYear"),
            jira_default_name=normalize_value(
                record.get("FRM_JiraDefaultName__c", "")
            ),
            ga_client_id=normalize_value(record.get("GACLIENTID__c", "")),
            ga_track_id=normalize_value(record.get("GATRACKID__c", "")),
            ga_user_id=normalize_value(record.get("GAUSERID__c", "")),
            is_global=normalize_value(record.get("Global__c", "")),
            has_opportunity_lineitem=normalize_value(
                record.get("HasOpportunityLineItem", "")
            ),
            has_overdue_task=normalize_value(record.get("HasOverdueTask", "")),
            hasproposal=normalize_value(record["HasProposal__c"]),
            is_closed=normalize_value(record["IsClosed"]),
            is_won=normalize_value(record["IsWon"]),
            jira_component_required=normalize_value(
                record["Jira_component_required__c"]
            ),
            jira_estimated_work_load=normalize_value(
                record.get("Jira_Estimated_Work_Load__c", "")
            ),
            jira_number=normalize_value(record.get("Jira_Number__c", "")),
            jira_work_load=normalize_value(
                record.get("Jira_Work_Load__c", "")
            ),
            jira_component_url=normalize_value(
                record.get("JiraComponentURL__c", "")
            ),
            lead_id=normalize_value(record.get("LeadId__c", "")),
            lead_source=normalize_value(record.get("LeadSource", "")),
            google_funding_opportunity=normalize_value(
                record.get("LKP_GoogleFundingOpportunity__c", "")
            ),
            loss_reason=normalize_value(record.get("Loss_Reason__c", "")),
            market_scope=normalize_value(record.get("Market_Scope__c", "")),
            ms_account_company_invoicing=normalize_value(
                record.get("MS_Account_Company_Invoicing__c", "")
            ),
            ms_account_invoice_country_code=normalize_value(
                record.get("MS_Account_Invoice_Country_Code__c", "")
            ),
            ms_company_origin=normalize_value(
                record.get("MS_Company_Origin__c", "")
            ),
            opportunity_name=normalize_value(record.get("Name", "")),
            opportunity_name_short=normalize_value(
                record.get("Opportunity_Name_Short__c", "")
            ),
            opportunity_requestor=normalize_value(
                record.get("Opportunity_requestor__c", "")
            ),
            owner_id=normalize_value(record.get("OwnerId", "")),
            probability=float(record.get("Probability", 0.0)),
            record_type_id=normalize_value(record.get("RecordTypeId", "")),
            roi_analysis_completed=normalize_value(
                record.get("ROI_Analysis_Completed__c", "")
            ),
            associated_services=normalize_value(
                record.get("Servicios_Asociados__c", "")
            ),
            stage_name=normalize_value(record.get("StageName", "")),
            start_date=normalize_value(record.get("Start_Date__c", "")),
            tier_short=normalize_value(record.get("Tier_Short__c", "")),
            total_opportunity_quantity=normalize_value(
                record.get("TotalOpportunityQuantity", "")
            ),
            year_created=_get_year_created("Year_Created__c"),
            opportunity_line_items=opportunity_line_items,
            lkp_project=normalize_value(record.get("LKP_Project__c", "")),
        )

    def to_dict(self):
        return {
            "opportunity_id": self.opportunity_id,
            "account_billing_country": self.account_billing_country,
            "account_owner": self.account_owner,
            "account_id": self.account_id,
            "amount": self.amount,
            "amount_eur": self.amount_eur,
            "campaign_id": self.campaign_id,
            "close_month_formula": self.close_month_formula,
            "close_date": self.close_date,
            "contact_id": self.contact_id,
            "curreny_iso_code": self.curreny_iso_code,
            "end_date": self.end_date,
            "expected_revenue": self.expected_revenue,
            "fiscal": self.fiscal,
            "fiscal_quarter": self.fiscal_quarter,
            "fiscal_year": self.fiscal_year,
            "jira_default_name": self.jira_default_name,
            "ga_client_id": self.ga_client_id,
            "ga_track_id": self.ga_track_id,
            "ga_user_id": self.ga_user_id,
            "is_global": self.is_global,
            "has_opportunity_lineitem": self.has_opportunity_lineitem,
            "has_overdue_task": self.has_overdue_task,
            "hasproposal": self.hasproposal,
            "is_closed": self.is_closed,
            "is_won": self.is_won,
            "jira_component_required": self.jira_component_required,
            "jira_estimated_work_load": self.jira_estimated_work_load,
            "jira_number": self.jira_number,
            "jira_work_load": self.jira_work_load,
            "jira_component_url": self.jira_component_url,
            "lead_id": self.lead_id,
            "lead_source": self.lead_source,
            "google_funding_opportunity": self.google_funding_opportunity,
            "loss_reason": self.loss_reason,
            "market_scope": self.market_scope,
            "ms_account_company_invoicing": self.ms_account_company_invoicing,
            "ms_account_invoice_country_code": self.ms_account_invoice_country_code,  # noqa: E501
            "ms_company_origin": self.ms_company_origin,
            "opportunity_name": self.opportunity_name,
            "opportunity_name_short": self.opportunity_name_short,
            "opportunity_requestor": self.opportunity_requestor,
            "owner_id": self.owner_id,
            "probability": self.probability,
            "record_type_id": self.record_type_id,
            "roi_analysis_completed": self.roi_analysis_completed,
            "associated_services": self.associated_services,
            "stage_name": self.stage_name,
            "start_date": self.start_date,
            "tier_short": self.tier_short,
            "total_opportunity_quantity": self.total_opportunity_quantity,
            "year_created": self.year_created,
            "opportunity_line_items": self.opportunity_line_items,
            "lkp_project": self.lkp_project,
        }

==> ms_salesforce_api-2.4.0-py3-none-any.whl: ms_salesforce_api/salesforce/api/opportunity/dto/OpportunityDTO.py <==
from datetime import datetime

from ms_salesforce_api.salesforce.helpers.string import normalize_value

MONTHS = {
    "January": "01",
    "February": "02",
    "March": "03",
    "April": "04",
    "May": "05",
    "June": "06",
    "July": "07",
    "August": "08",
    "September": "09",
    "October": "10",
    "November": "11",
    "December": "12",
}


class OpportunityLineItemDTO(object):
    def __init__(
        self,
        product_id,
        profit_center_name,
        country,
        opportunity_id,
        product_name,
        quantity,
        unit_price,
    ):
        self.product_id = product_id
        self.profit_center_name = profit_center_name
        self.country = country
        self.opportunity_id = opportunity_id
        self.product_name = product_name
        self.quantity = quantity
        self.unit_price = unit_price

    @staticmethod
    def from_salesforce_record(line_item_record, opportunity_id):
        product_name = line_item_record.get("FRM_ProductName__c", "")
        quantity = line_item_record.get("Quantity", 0.0)
        unit_price = line_item_record.get("UnitPrice", 0.0)
        product = line_item_record.get("Product2", {})
        profit_center = product.get("LKP_ProfitCenter__r", {})
        profit_center_name = ""
        country = ""

        if profit_center:
            profit_center_name = normalize_value(profit_center.get("Name", ""))
            country = normalize_value(profit_center.get("PCK_Country__c", ""))

        return OpportunityLineItemDTO(
            product_id=product.get("Id", ""),
            profit_center_name=profit_center_name,
            country=country,
            opportunity_id=opportunity_id,
            product_name=product_name,
            quantity=quantity,
            unit_price=unit_price,
        )

    def to_dict(self):
        return {
            "product_id": self.product_id,
            "profit_center_name": self.profit_center_name,
            "country": self.country,
            "opportunity_id": self.opportunity_id,
            "product_name": self.product_name,
            "quantity": self.quantity,
            "unit_price": self.unit_price,
        }


class OpportunityDTO(object):
    def __init__(
        self,
        opportunity_id,
        account_billing_country,
        account_owner,
        account_id,
        amount,
        amount_eur,
        campaign_id,
        close_month_formula,
        close_date,
        contact_id,
        curreny_iso_code,
        end_date,
        expected_revenue,
        fiscal,
        fiscal_quarter,
        fiscal_year,
        jira_default_name,
        ga_client_id,
        ga_track_id,
        ga_user_id,
        is_global,
        has_opportunity_lineitem,
        has_overdue_task,
        hasproposal,
        is_closed,
        is_won,
        jira_component_required,
        jira_estimated_work_load,
        jira_number,
        jira_work_load,
        jira_component_url,
        lead_id,
        lead_source,
        google_funding_opportunity,
        loss_reason,
        market_scope,
        ms_account_company_invoicing,
        ms_account_invoice_country_code,
        ms_company_origin,
        opportunity_name,
        opportunity_name_short,
        opportunity_requestor,
        owner_id,
        probability,
        record_type_id,
        roi_analysis_completed,
        associated_services,
        stage_name,
        start_date,
        tier_short,
        total_opportunity_quantity,
        year_created,
        opportunity_line_items,
        lkp_project,
    ):
        self.opportunity_id = opportunity_id
        self.account_billing_country = account_billing_country
        self.account_owner = account_owner
        self.account_id = account_id
        self.amount = amount
        self.amount_eur = amount_eur
        self.campaign_id = campaign_id
        self.close_month_formula = close_month_formula
        self.close_date = close_date
        self.contact_id = contact_id
        self.curreny_iso_code = curreny_iso_code
        self.end_date = end_date
        self.expected_revenue = expected_revenue
        self.fiscal = fiscal
        self.fiscal_quarter = fiscal_quarter
        self.fiscal_year = fiscal_year
        self.jira_default_name = jira_default_name
        self.ga_client_id = ga_client_id
        self.ga_track_id = ga_track_id
        self.ga_user_id = ga_user_id
        self.is_global = is_global
        self.has_opportunity_lineitem = has_opportunity_lineitem
        self.has_overdue_task = has_overdue_task
        self.hasproposal = hasproposal
        self.is_closed = is_closed
        self.is_won = is_won
        self.jira_component_required = jira_component_required
        self.jira_estimated_work_load = jira_estimated_work_load
        self.jira_number = jira_number
        self.jira_work_load = jira_work_load
        self.jira_component_url = jira_component_url
        self.lead_id = lead_id
        self.lead_source = lead_source
        self.google_funding_opportunity = google_funding_opportunity
        self.loss_reason = loss_reason
        self.market_scope = market_scope
        self.ms_account_company_invoicing = ms_account_company_invoicing
        self.ms_account_invoice_country_code = ms_account_invoice_country_code
        self.ms_company_origin = ms_company_origin
        self.opportunity_name = opportunity_name
        self.opportunity_name_short = opportunity_name_short
        self.opportunity_requestor = opportunity_requestor
        self.owner_id = owner_id
        self.probability = probability
        self.record_type_id = record_type_id
        self.roi_analysis_completed = roi_analysis_completed
        self.associated_services = associated_services
        self.stage_name = stage_name
        self.start_date = start_date
        self.tier_short = tier_short
        self.total_opportunity_quantity = total_opportunity_quantity
        self.year_created = year_created
        self.opportunity_line_items = opportunity_line_items
        self.lkp_project = lkp_project

    @staticmethod
    def from_salesforce_record(record):
        def _get_year_created(key: str):
            try:
                year = int(record[key])
                # We set allways the January first date because they want
                # a Date field for this value.
                return f"{year}-01-01"

            except (TypeError, KeyError):
                return ""

        def _get_close_month_formula():
            date_str = record.get("Close_Month_Formula__c", "")
            day, month = date_str.split(" ")

            month_num = MONTHS.get(month)

            date_formatted = (
                f"{datetime.now().year}-{month_num}-{day.zfill(2)}"
            )

            return date_formatted

        opportunity_line_items = record.get("OpportunityLineItems", {})
        if opportunity_line_items and isinstance(opportunity_line_items, dict):
            line_items_records = record.get("OpportunityLineItems", {}).get(
                "records", []
            )
            opportunity_line_items = [
                OpportunityLineItemDTO.from_salesforce_record(
                    line_item,
                    record["Id"],
                ).to_dict()
                for line_item in line_items_records
            ]
        else:
            opportunity_line_items = []

        return OpportunityDTO(
            opportunity_id=record["Id"],
            account_billing_country=normalize_value(
                record.get("Account_Billing_Country__c", "")
            ),
            account_owner=normalize_value(record.get("Account_owner__c", "")),
            account_id=normalize_value(record.get("AccountId", "")),
            amount=record.get("Amount", 0.0),
            amount_eur=record.get("Amount_EUR__c", 0.0),
            campaign_id=normalize_value(record.get("CampaignId", "")),
            close_month_formula=_get_close_month_formula(),
            close_date=normalize_value(record.get("CloseDate", "")),
            contact_id=normalize_value(record.get("ContactId", "")),
            curreny_iso_code=normalize_value(
                record.get("CurrencyIsoCode", "")
            ),
            end_date=normalize_value(record.get("EndDate__c", "")),
            expected_revenue=normalize_value(
                record.get("ExpectedRevenue", "")
            ),
            fiscal=normalize_value(record.get("Fiscal", "")),
            fiscal_quarter=normalize_value(record.get("FiscalQuarter", "")),
            fiscal_year=_get_year_created("FiscalYear"),
            jira_default_name=normalize_value(
                record.get("FRM_JiraDefaultName__c", "")
            ),
            ga_client_id=normalize_value(record.get("GACLIENTID__c", "")),
            ga_track_id=normalize_value(record.get("GATRACKID__c", "")),
            ga_user_id=normalize_value(record.get("GAUSERID__c", "")),
            is_global=normalize_value(record.get("Global__c", "")),
            has_opportunity_lineitem=normalize_value(
                record.get("HasOpportunityLineItem", "")
            ),
            has_overdue_task=normalize_value(record.get("HasOverdueTask", "")),
            hasproposal=normalize_value(record["HasProposal__c"]),
            is_closed=normalize_value(record["IsClosed"]),
            is_won=normalize_value(record["IsWon"]),
            jira_component_required=normalize_value(
                record["Jira_component_required__c"]
            ),
            jira_estimated_work_load=normalize_value(
                record.get("Jira_Estimated_Work_Load__c", "")
            ),
            jira_number=normalize_value(record.get("Jira_Number__c", "")),
            jira_work_load=normalize_value(
                record.get("Jira_Work_Load__c", "")
            ),
            jira_component_url=normalize_value(
                record.get("JiraComponentURL__c", "")
            ),
            lead_id=normalize_value(record.get("LeadId__c", "")),
            lead_source=normalize_value(record.get("LeadSource", "")),
            google_funding_opportunity=normalize_value(
                record.get("LKP_GoogleFundingOpportunity__c", "")
            ),
            loss_reason=normalize_value(record.get("Loss_Reason__c", "")),
            market_scope=normalize_value(record.get("Market_Scope__c", "")),
            ms_account_company_invoicing=normalize_value(
                record.get("MS_Account_Company_Invoicing__c", "")
            ),
            ms_account_invoice_country_code=normalize_value(
                record.get("MS_Account_Invoice_Country_Code__c", "")
            ),
            ms_company_origin=normalize_value(
                record.get("MS_Company_Origin__c", "")
            ),
            opportunity_name=normalize_value(record.get("Name", "")),
            opportunity_name_short=normalize_value(
                record.get("Opportunity_Name_Short__c", "")
            ),
            opportunity_requestor=normalize_value(
                record.get("Opportunity_requestor__c", "")
            ),
            owner_id=normalize_value(record.get("OwnerId", "")),
            probability=float(record.get("Probability", 0.0)),
            record_type_id=normalize_value(record.get("RecordTypeId", "")),
            roi_analysis_completed=normalize_value(
                record.get("ROI_Analysis_Completed__c", "")
            ),
            associated_services=normalize_value(
                record.get("Servicios_Asociados__c", "")
            ),
            stage_name=normalize_value(record.get("StageName", "")),
            start_date=normalize_value(record.get("Start_Date__c", "")),
            tier_short=normalize_value(record.get("Tier_Short__c", "")),
            total_opportunity_quantity=normalize_value(
                record.get("TotalOpportunityQuantity", "")
            ),
            year_created=_get_year_created("Year_Created__c"),
            opportunity_line_items=opportunity_line_items,
            lkp_project=normalize_value(record.get("LKP_Project__c", "")),
        )

    def to_dict(self):
        return {
            "opportunity_id": self.opportunity_id,
            "account_billing_country": self.account_billing_country,
            "account_owner": self.account_owner,
            "account_id": self.account_id,
            "amount": self.amount,
            "amount_eur": self.amount_eur,
            "campaign_id": self.campaign_id,
            "close_month_formula": self.close_month_formula,
            "close_date": self.close_date,
            "contact_id": self.contact_id,
            "curreny_iso_code": self.curreny_iso_code,
            "end_date": self.end_date,
            "expected_revenue": self.expected_revenue,
            "fiscal": self.fiscal,
            "fiscal_quarter": self.fiscal_quarter,
            "fiscal_year": self.fiscal_year,
            "jira_default_name": self.jira_default_name,
            "ga_client_id": self.ga_client_id,
            "ga_track_id": self.ga_track_id,
            "ga_user_id": self.ga_user_id,
            "is_global": self.is_global,
            "has_opportunity_lineitem": self.has_opportunity_lineitem,
            "has_overdue_task": self.has_overdue_task,
            "hasproposal": self.hasproposal,
            "is_closed": self.is_closed,
            "is_won": self.is_won,
            "jira_component_required": self.jira_component_required,
            "jira_estimated_work_load": self.jira_estimated_work_load,
            "jira_number": self.jira_number,
            "jira_work_load": self.jira_work_load,
            "jira_component_url": self.jira_component_url,
            "lead_id": self.lead_id,
            "lead_source": self.lead_source,
            "google_funding_opportunity": self.google_funding_opportunity,
            "loss_reason": self.loss_reason,
            "market_scope": self.market_scope,
            "ms_account_company_invoicing": self.ms_account_company_invoicing,
            "ms_account_invoice_country_code": self.ms_account_invoice_country_code,  # noqa: E501
            "ms_company_origin": self.ms_company_origin,
            "opportunity_name": self.opportunity_name,
            "opportunity_name_short": self.opportunity_name_short,
            "opportunity_requestor": self.opportunity_requestor,
            "owner_id": self.owner_id,
            "probability": self.probability,
            "record_type_id": self.record_type_id,
            "roi_analysis_completed": self.roi_analysis_completed,
            "associated_services": self.associated_services,
            "stage_name": self.stage_name,
            "start_date": self.start_date,
            "tier_short": self.tier_short,
            "total_opportunity_quantity": self.total_opportunity_quantity,
            "year_created": self.year_created,
            "opportunity_line_items": self.opportunity_line_items,
            "lkp_project": self.lkp_project,
        }
